pub struct TofPacket {
pub packet_type: TofPacketType,
pub payload: Vec<u8>,
pub no_write_to_disk: bool,
pub no_send_over_nw: bool,
pub creation_time: Instant,
pub valid: bool,
pub tof_paddles: Arc<HashMap<u8, TofPaddle>>,
}Expand description
Internal Tof communication protocol. Simple, yet powerful
A TofPacket has the following layout on disk HEAD : u16 = 0xAAAA TYPE : u8 = PacketType SIZE : u32 PAYLOAD : [u8;6-SIZE] TAIL : u16 = 0x5555
The total packet size is thus 13 + SIZE
Fields
packet_type: TofPacketTypeType of the structure encoded in payload
payload: Vec<u8>The bytestream encoded structure
no_write_to_disk: boolmark a packet as not eligible to be written to disk
no_send_over_nw: boolmark a packet as not eligible to be sent over network FIXME - future extension
creation_time: Instantcreation_time for the instance
valid: booltof_paddles: Arc<HashMap<u8, TofPaddle>>Implementations
Sourceimpl TofPacket
impl TofPacket
pub fn new() -> Self
Sourcepub fn zmq_payload_brdcast(&self) -> Vec<u8> ⓘ
pub fn zmq_payload_brdcast(&self) -> Vec<u8> ⓘ
Generate a bytestream of self for ZMQ, prefixed with BRCT so all RBs will see it
Sourcepub fn zmq_payload_rb(&self, rb_id: u8) -> Vec<u8> ⓘ
pub fn zmq_payload_rb(&self, rb_id: u8) -> Vec<u8> ⓘ
Generate a bytestream of self for ZMQ, prefixed with RBX, to address only a certain board
Sourcepub fn unpack<T>(&self) -> Result<T, SerializationError>where
T: TofPackable + Serialization,
pub fn unpack<T>(&self) -> Result<T, SerializationError>where
T: TofPackable + Serialization,
Unpack the TofPacket and return its content
pub fn age(&self) -> u64